@@ -45,8 +45,8 @@ THE SOFTWARE. */
 
 #include "MainMenuView.hpp"
 #include "ThereminView.hpp"
+#include "KeyboardView.hpp"
 #include "ListenView.hpp"
-#include "OptionsDialog.hpp"
 #include "Preferences.hpp"
 
 
@@ -76,6 +76,7 @@ class MainWindow :
 	MainMenuView mainMenuView;
 	ThereminView thereminView;
 	ListenView listenView;
+	KeyboardView keyboardView;
 
 	ting::Signal0 openOptionsSignal;
 
@@ -92,6 +93,7 @@ public:
 	void ShowMainMenuScreen(){
 		this->notebook.set_current_page(0);
 		this->openOptionsSignal.DisconnectAll();
+		this->optionsMenuItem.set_sensitive(false);
 	}
 
 	void ShowThereminScreen(){
@@ -101,11 +103,25 @@ public:
 				&this->thereminView,
 				&ThereminView::ShowOptionsDialog
 			);
+		this->optionsMenuItem.set_sensitive(true);
 	}
 
 	void ShowListenOthersScreen(){
 		this->notebook.set_current_page(2);
 		this->openOptionsSignal.DisconnectAll();
+		this->optionsMenuItem.set_sensitive(false);
+
+		this->listenView.OnNextButtonClicked();//send first "next" command to server
+	}
+
+	void ShowKeyboardScreen(){
+		this->notebook.set_current_page(3);
+		this->openOptionsSignal.DisconnectAll();
+		this->openOptionsSignal.Connect(
+				&this->keyboardView,
+				&KeyboardView::ShowOptionsDialog
+			);
+		this->optionsMenuItem.set_sensitive(true);
 	}
 
 	bool OnKeyPress(GdkEventKey* event);
