@@ -38,6 +38,7 @@ THE SOFTWARE. */
 #include "../aumiks.hpp"
 
 #include "PluckedString.hpp"
+#include "Bowed.hpp"
 
 namespace aumiks{
 
@@ -65,6 +66,7 @@ public:
 };
 
 
+
 class PluckedStringInstrument : public Instrument{
 public:
 	class Channel : public Instrument::Channel{
@@ -105,7 +107,10 @@ public:
 	};
 
 	//override
-	Ref<Instrument::Channel> CreateChannel();
+	Ref<Instrument::Channel> CreateChannel(){
+		Ref<PluckedStringInstrument::Channel> ch(new PluckedStringInstrument::Channel());
+		return ch;
+	}
 
 	static inline ting::Ref<PluckedStringInstrument> New(){
 		return ting::Ref<PluckedStringInstrument>(new PluckedStringInstrument());
@@ -114,6 +119,49 @@ public:
 
 
 
+class BowedInstrument : public Instrument{
+public:
+	class Channel : public Instrument::Channel{
+		Bowed bowed;
+
+	public:
+		Channel(){
+			this->bowed.SetFrequency(220);
+//			this->pluckedString.SetFrequency(220);
+//			this->pluckedString.SetLoopGain(1);
+//			this->pluckedString.SetLoopFilterCoefs(0.95, 0.05);
+		}
+
+		//override
+		void SetFrequency(float freq){
+			this->bowed.SetFrequency(freq);
+		}
+
+	protected:
+		//override
+		void OnStart(){
+			this->bowed.StartBowing(1);
+//			this->pluckedString.Pluck(1.0);
+//			this->state = PLAYING;
+		}
+	private:
+		//override
+		bool MixToMixBuf(Array<s32>& mixBuf);
+	};
+
+	//override
+	Ref<Instrument::Channel> CreateChannel(){
+		Ref<BowedInstrument::Channel> ch(new BowedInstrument::Channel());
+		return ch;
+	}
+
+	static inline ting::Ref<BowedInstrument> New(){
+		return ting::Ref<BowedInstrument>(new BowedInstrument());
+	}
+};
+
+
+
 class SineWaveInstrument : public Instrument{
 public:
 
@@ -153,13 +201,7 @@ public:
 
 		//override
 		// freq in Hz
-		void SetFrequency(float freq){
-			this->phaseStep = D2Pi<real>() * real(freq) / real(44100);
-			this->attackTime = 1000.0f * 30.0f / freq;
-			this->decayTime = 1000.0f * 50.0f / freq;
-			this->sustainLevel = 0.8f;
-			this->releaseTime = 1000.0f * 30.0f / freq;
-		}
+		void SetFrequency(float freq);
 
 	private:
 		//override
@@ -312,4 +354,22 @@ public:
 
 
 
+class ViolinInstrument : public SampledInstrument{
+	ViolinInstrument() :
+			SampledInstrument(GenerateSample(), GetADSRParams())
+	{}
+
+
+	static Ref<Sample> GenerateSample();
+
+	static ADSRParams GetADSRParams();
+
+public:
+	static inline ting::Ref<ViolinInstrument> New(){
+		return ting::Ref<ViolinInstrument>(new ViolinInstrument());
+	}
+};
+
+
+
 }//~namespace
